@@ -9,7 +9,7 @@
 #'
 #' @param ... Other relevant parameters for \code{\link{graph.spectral.density}}.
 #'
-#' @return A list with class "statGraph" containing the following components:
+#' @return A list with class 'statGraph' containing the following components:
 #' \item{\code{method:}}{ a string indicating the used method.}
 #' \item{\code{info:}}{ a string showing details about the method.}
 #' \item{\code{data.name:}}{ a string with the data's name(s).}
@@ -30,21 +30,22 @@
 #' entropy
 #'
 #' @export
-graph.entropy <- function(Graph,...) {
-  if(!valid.input(Graph)) stop("The input should be an igraph object!")
-  data.name <- deparse(substitute(Graph))
-  # compute the entropy
-  f <- graph.spectral.density(Graph, ...)
+graph.entropy <- function(Graph, ...) {
+    if (!valid.input(Graph))
+        stop("The input should be an igraph object!")
+    data.name <- deparse(substitute(Graph))
+    # compute the entropy
+    f <- graph.spectral.density(Graph, ...)
 
-  if (sum(is.na(f)) > 0)
-    return(NA)
-  y <- f$y
-  valid_idx <- which(y != 0)
-  y[valid_idx] <- y[valid_idx]*log(y[valid_idx])
-  entropy <- -trapezoidSum(f$x, y)
-  # return class
-  method_info <- "Spectral Entropy of a Graph"
-  output <- list(method=method_info, info=f$info, data.name=data.name, entropy=entropy)
-  class(output) <- "statGraph"
-  return(output)
+    if (sum(is.na(f)) > 0)
+        return(NA)
+    y <- f$y
+    valid_idx <- which(y != 0)
+    y[valid_idx] <- y[valid_idx] * log(y[valid_idx])
+    entropy <- -trapezoidSum(f$x, y)
+    # return class
+    method_info <- "Spectral Entropy of a Graph"
+    output <- list(method = method_info, info = f$info, data.name = data.name, entropy = entropy)
+    class(output) <- "statGraph"
+    return(output)
 }
